# POST installation example services.

## Disclaimer

### This assumes all the pods have managed to run correctly. 

```shell
kubectl get pods --kubeconfig ksetup/Exported/kubeconfig.conf -A
```

```text
NAMESPACE        NAME                                       READY   STATUS    RESTARTS        AGE
default          helloworld-nginx-76cbfb674f-xn9hj          1/1     Running   2 (4h53m ago)   7h58m
kube-system      calico-kube-controllers-85578c44bf-gdpdm   1/1     Running   2 (4h53m ago)   9h
kube-system      calico-node-fpjd2                          1/1     Running   2 (4h53m ago)   9h
kube-system      coredns-5d78c9869d-pjpmz                   1/1     Running   2 (4h53m ago)   9h
kube-system      coredns-5d78c9869d-sj9bh                   1/1     Running   2 (4h53m ago)   9h
kube-system      etcd-pi4.filter.home                       1/1     Running   3 (4h53m ago)   9h
kube-system      kube-apiserver-pi4.filter.home             1/1     Running   3 (4h53m ago)   9h
kube-system      kube-controller-manager-pi4.filter.home    1/1     Running   3 (4h53m ago)   9h
kube-system      kube-proxy-9md6w                           1/1     Running   2 (4h53m ago)   9h
kube-system      kube-scheduler-pi4.filter.home             1/1     Running   3 (4h53m ago)   9h
metallb-system   controller-595f88d88f-vx6vx                1/1     Running   3 (4h53m ago)   7h27m
metallb-system   speaker-qls8v                              1/1     Running   4 (40m ago)     7h27m
```


## Deployment

### Istio

#### Config

```shell
istioctl install  --kubeconfig ksetup/Exported/kubeconfig.conf -f PostInstall_Example_Config_Files/IstioOperator_Config.yaml
```

<pre>
This will install the Istio 1.18.2 minimal profile with [&quot;Istio core&quot; &quot;Istiod&quot;] components into the cluster. Proceed? (y/N) y
<span style="color:#7F3FBF">✔</span> Istio core installed                                                                                                                                                                                                                    
<span style="color:#7F3FBF">✔</span> Istiod installed                                                                                                                                                                                                                        
<span style="color:#7F3FBF">✔</span> Installation complete
Making this installation the default for injection and validation.
</pre>

#### Ingress

```shell
istioctl install  --kubeconfig ksetup/Exported/kubeconfig.conf -f PostInstall_Example_Config_Files/IstioOperator_Ingress.yaml
```

<pre>
This will install the Istio 1.18.2 empty profile into the cluster. Proceed? (y/N) y
<span style="color:#7F3FBF">✔</span> Ingress gateways installed                                                                                                                                                                                                              
<span style="color:#7F3FBF">✔</span> Installation complete
</pre>

#### Check status

We can see that the Load Balancer we deployed, the `External-IP` field is set to "pending". That's expected, since we have no service providing an IP for us.

```shell
kubectl get svc --kubeconfig ksetup/Exported/kubeconfig.conf -A
```

<pre>
NAMESPACE        NAME                   TYPE           CLUSTER-IP       EXTERNAL-IP   PORT(S)                                      AGE
default          helloworld             ClusterIP      10.107.193.163   &lt;none&gt;        80/TCP                                       8h
default          kubernetes             ClusterIP      10.96.0.1        &lt;none&gt;        443/TCP                                      9h
istio-system     istio-ingressgateway   LoadBalancer   10.96.74.132     &lt;pending&gt;     15021:31543/TCP,80:31989/TCP,443:31913/TCP   64s
istio-system     istiod                 ClusterIP      10.108.199.210   &lt;none&gt;        15010/TCP,15012/TCP,443/TCP,15014/TCP        79s
kube-system      kube-dns               ClusterIP      10.96.0.10       &lt;none&gt;        53/UDP,53/TCP,9153/TCP                       9h
metallb-system   webhook-service        ClusterIP      10.100.237.6     &lt;none&gt;        443/TCP                                      7h42m
</pre>



## MetalLB

Let's work on our way to provide an IP for the that are on "pending" status.

### Deploy

```shell
kubectl create  --kubeconfig ksetup/Exported/kubeconfig.conf -f PostInstall_Example_Config_Files/MetalLB.yaml
```

```text
ipaddresspool.metallb.io/pool1-group created
l2advertisement.metallb.io/pool1-advert created
```

### What did we deploy?

#### pool1-group

States a range/group of IP addresses to use for our services.

- `192.168.1.72/30`

#### pool1-advert

Advertises the desired IP ranges (in our scenario it's `pool1-group`) to the network, that way resources can reach out to such.

### Check status

Now ur services are allowed to have an IP within the "reserved"/configured range. 

```shell
kubectl get svc --kubeconfig ksetup/Exported/kubeconfig.conf -n istio-system istio-ingressgateway
```

```text
NAME                   TYPE           CLUSTER-IP       EXTERNAL-IP    PORT(S)                                      AGE
istio-ingressgateway   LoadBalancer   10.96.74.132   192.168.1.72   15021:31543/TCP,80:31989/TCP,443:31913/TCP   9m21s
```

## Test ingress.

### HealthCheck

Healthcheck passes correctly.

```shell
curl 192.168.1.72:15021/healthz/ready -I
```

```text
HTTP/1.1 200 OK
date: Sat, 29 Jul 2023 22:59:49 GMT
x-envoy-upstream-service-time: 0
server: envoy
transfer-encoding: chunked
```

### Deploy mock resources

```shell
kubectl create  --kubeconfig ksetup/Exported/kubeconfig.conf -f PostInstall_Example_Config_Files/Test_Services
```

```text
deployment.apps/helloworld-nginx created
gateway.networking.istio.io/helloworld-gateway created
service/helloworld created
virtualservice.networking.istio.io/helloworld-vs created
```

### Test mock resources

We are able to receive response from the Nginx Deployment.

```shell
curl 192.168.1.72/helloworld 
```

```text
<!DOCTYPE html>
<html>
<head>
<title>Welcome to nginx!</title>
<style>
html { color-scheme: light dark; }
body { width: 35em; margin: 0 auto;
font-family: Tahoma, Verdana, Arial, sans-serif; }
</style>
</head>
<body>
<h1>Welcome to nginx!</h1>
<p>If you see this page, the nginx web server is successfully installed and
working. Further configuration is required.</p>

<p>For online documentation and support please refer to
<a href="http://nginx.org/">nginx.org</a>.<br/>
Commercial support is available at
<a href="http://nginx.com/">nginx.com</a>.</p>

<p><em>Thank you for using nginx.</em></p>
</body>
</html>
```